ExtendedRouteType

Enum ExtendedRouteType 

#[repr(i16)]
pub enum ExtendedRouteType {
Show 81 variants Railway = 100, HighSpeedRail = 101, LongDistanceTrains = 102, InterRegionalRail = 103, CarTransportRail = 104, SleeperRail = 105, RegionalRail = 106, TouristRailway = 107, RailShuttleWithinComplex = 108, SuburbanRailway = 109, ReplacementRail = 110, SpecialRail = 111, LorryTransportRail = 112, OtherRail = 113, CrossCountryRail = 114, VehicleTransportRail = 115, RackAndPinionRailway = 116, AdditionalRail = 117, Coach = 200, InternationalCoach = 201, NationalCoach = 202, ShuttleCoach = 203, RegionalCoach = 204, SpecialCoach = 205, SightseeingCoach = 206, TouristCoach = 207, CommuterCoach = 208, OtherCoach = 209, UrbanRailway = 400, Metro = 401, Underground = 402, UrbanRailwayServiceDetail = 403, OtherUrbanRailway = 404, Monorail = 405, Bus = 700, RegionalBus = 701, ExpressBus = 702, StoppingBus = 703, LocalBus = 704, NightBus = 705, PostBus = 706, SpecialNeedsBus = 707, MobilityBus = 708, MobilityBusForRegisteredDisabled = 709, SightseeingBus = 710, ShuttleBus = 711, SchoolBus = 712, SchoolAndPublicServiceBus = 713, RailReplacementBus = 714, DemandAndResponseBus = 715, OtherBus = 716, Trolleybus = 800, Tram = 900, CityTram = 901, LocalTram = 902, RegionalTram = 903, SightseeingTram = 904, ShuttleTram = 905, OtherTram = 906, WaterTransport = 1_000, Air = 1_100, Ferry = 1_200, AerialLift = 1_300, Telecabin = 1_301, CableCar = 1_302, Elevator = 1_303, ChairLift = 1_304, DragLift = 1_305, SmallTelecabin = 1_306, OtherTelecabin = 1_307, Funicular = 1_400, Taxi = 1_500, CommunalTaxi = 1_501, WaterTaxi = 1_502, RailTaxi = 1_503, BikeTaxi = 1_504, LicensedTaxi = 1_505, PrivateHireServiceVehicle = 1_506, OtherTaxi = 1_507, MiscellaneousService = 1_700, HorseDrawnCarriage = 1_702,
}
Variants



Railway = 100

Railway Service.



HighSpeedRail = 101

High Speed Rail Service. Examples: TGV (FR), ICE (DE), Eurostar (GB).



LongDistanceTrains = 102

Long Distance Trains. Examples: InterCity/EuroCity.



InterRegionalRail = 103

Inter Regional Rail Service. Examples: InterRegio (DE), Cross County Rail (GB).



CarTransportRail = 104

Car Transport Rail Service.



SleeperRail = 105

Sleeper Rail Service. Example: GNER Sleeper (GB).



RegionalRail = 106

Regional Rail Service. Examples: TER (FR), Regionalzug (DE).



TouristRailway = 107

Tourist Railway Service. Example: Romney, Hythe & Dymchurch (GB).



RailShuttleWithinComplex = 108

Rail Shuttle (Within Complex). Examples: Gatwick Shuttle (GB), Sky Line (DE).



SuburbanRailway = 109

Suburban Railway. Examples: S-Bahn (DE), RER (FR), S-tog (Kopenhagen).



ReplacementRail = 110

Replacement Rail Service.



SpecialRail = 111

Special Rail Service.



LorryTransportRail = 112

Lorry Transport Rail Service.



OtherRail = 113

All Rail Services.



CrossCountryRail = 114

Cross-Country Rail Service.



VehicleTransportRail = 115

Vehicle Transport Rail Service.



RackAndPinionRailway = 116

Rack and Pinion Railway. Examples: Rochers de Naye (CH), Dolderbahn (CH).



AdditionalRail = 117

Additional Rail Service.



Coach = 200

Coach Service.



InternationalCoach = 201

International Coach Service. Examples: EuroLine, Touring.



NationalCoach = 202

National Coach Service. Example: National Express (GB).



ShuttleCoach = 203

Shuttle Coach Service. Examples: Roissy Bus (FR), Reading-Heathrow (GB).



RegionalCoach = 204

Regional Coach Service.



SpecialCoach = 205

Special Coach Service.



SightseeingCoach = 206

Sightseeing Coach Service.



TouristCoach = 207

Tourist Coach Service.



CommuterCoach = 208

Commuter Coach Service.



OtherCoach = 209

All Coach Services.



UrbanRailway = 400

Urban Railway Service.



Metro = 401

Metro Service. Example: Métro de Paris.



Underground = 402

Underground Service. Examples: London Underground, U-Bahn.



UrbanRailwayServiceDetail = 403

Urban Railway Service.



OtherUrbanRailway = 404

All Urban Railway Services.



Monorail = 405

Monorail.



Bus = 700

Bus Service.



RegionalBus = 701

Regional Bus Service. Example: Eastbourne-Maidstone (GB).



ExpressBus = 702

Express Bus Service. Example: X19 Wokingham-Heathrow (GB).



StoppingBus = 703

Stopping Bus Service. Example: 38 London: Clapton Pond-Victoria (GB).



LocalBus = 704

Local Bus Service.



NightBus = 705

Night Bus Service. Example: N prefixed buses in London (GB).



PostBus = 706

Post Bus Service. Example: Maidstone P4 (GB).



SpecialNeedsBus = 707

Special Needs Bus.



MobilityBus = 708

Mobility Bus Service.



MobilityBusForRegisteredDisabled = 709

Mobility Bus for Registered Disabled.



SightseeingBus = 710

Sightseeing Bus.



ShuttleBus = 711

Shuttle Bus. Example: 747 Heathrow-Gatwick Airport Service (GB).



SchoolBus = 712

School Bus.



SchoolAndPublicServiceBus = 713

School and Public Service Bus.



RailReplacementBus = 714

Rail Replacement Bus Service.



DemandAndResponseBus = 715

Demand and Response Bus Service.



OtherBus = 716

All Bus Services.



Trolleybus = 800

Trolleybus Service.



Tram = 900

Tram Service.



CityTram = 901

City Tram Service.



LocalTram = 902

Local Tram Service. Examples: Munich (DE), Brussels (BE), Croydon (GB).



RegionalTram = 903

Regional Tram Service.



SightseeingTram = 904

Sightseeing Tram Service. Example: Blackpool Seafront (GB).



ShuttleTram = 905

Shuttle Tram Service.



OtherTram = 906

All Tram Services.



WaterTransport = 1_000

Water Transport Service.



Air = 1_100

Air Service.



Ferry = 1_200

Ferry Service.



AerialLift = 1_300

Aerial Lift Service. Examples: Telefèric de Montjuïc (ES), Saleve (CH), Roosevelt Island Tramway (US).



Telecabin = 1_301

Telecabin Service.



CableCar = 1_302

Cable Car Service.



Elevator = 1_303

Elevator Service.



ChairLift = 1_304

Chair Lift Service.



DragLift = 1_305

Drag Lift Service.



SmallTelecabin = 1_306

Small Telecabin Service.



OtherTelecabin = 1_307

All Telecabin Services.



Funicular = 1_400

Funicular Service. Example: Rigiblick (Zürich, CH).



Taxi = 1_500

Taxi Service.



CommunalTaxi = 1_501

Communal Taxi Service. Examples: Marshrutka (RU), dolmuş (TR).



WaterTaxi = 1_502

Water Taxi Service.



RailTaxi = 1_503

Rail Taxi Service.



BikeTaxi = 1_504

Bike Taxi Service.



LicensedTaxi = 1_505

Licensed Taxi Service.



PrivateHireServiceVehicle = 1_506

Private Hire Service Vehicle.



OtherTaxi = 1_507

All Taxi Services.



MiscellaneousService = 1_700

Miscellaneous Service.



HorseDrawnCarriage = 1_702

Horse-drawn Carriage.

Implementations

Source

impl ExtendedRouteType

pub fn to_standard_route_type(&self) -> RouteType

Convert extended route types to standard route types if possible. All route types that can not be represented in standard route types at all are kept as-is. This loses precision.