pub enum Error {
MissingFile(String),
ReferenceError(String),
NotFileNorDirectory(String),
InvalidTime(String),
InvalidColor(String),
IO(Error),
NamedFileIO {
file_name: String,
source: Box<dyn Error + Send + Sync>,
},
Fetch(Error),
CSVError {
file_name: String,
source: Error,
line_in_error: Option<LineError>,
},
Zip(ZipError),
}Expand description
An error that can occur when processing GTFS data.
Variants
MissingFile(String)
A mandatory file is not present in the archive
ReferenceError(String)
A file references an Id that is not present
NotFileNorDirectory(String)
The given path to the GTFS is neither a file nor a directory
InvalidTime(String)
The time is not given in the HH:MM:SS format
InvalidColor(String)
The color is not given in the RRGGBB format, without a leading #
IO(Error)
Generic Input/Output error while reading a file
NamedFileIO
Impossible to read a file
Fields
Fetch(Error)
Impossible to fetch the remote archive by the URL
CSVError
Impossible to read a CSV file
Fields
Zip(ZipError)
Error when trying to unzip the GTFS archive