pub struct Attribution {
pub attribution_id: Option<String>,
pub agency_id: Option<String>,
pub route_id: Option<String>,
pub trip_id: Option<String>,
pub organization_name: String,
pub is_producer: bool,
pub is_operator: bool,
pub is_authority: bool,
pub attribution_url: Option<String>,
pub attribution_email: Option<String>,
pub attribution_phone: Option<String>,
}Expand description
Attribution for a dataset
Fields
attribution_id: Option<String>Identifies an attribution for the dataset or a subset of it. This is mostly useful for translations.
agency_id: Option<String>Agency to which the attribution applies.
route_id: Option<String>Route to which the attribution applies.
trip_id: Option<String>Trip to which the attribution applies.
organization_name: StringName of the organization that the dataset is attributed to.
is_producer: boolWhether the organization is the producer
is_operator: boolWhether the organization is the operator
Whether the organization is a transport authority
attribution_url: Option<String>URL of the organization.
attribution_email: Option<String>Email of the organization.
attribution_phone: Option<String>Phone number of the organization.