pub struct FareAttribute {
    pub id: String,
    pub price: String,
    pub currency: String,
    pub payment_method: PaymentMethod,
    pub transfers: Transfers,
    pub agency_id: Option<String>,
    pub transfer_duration: Option<usize>,
}
Fields

id: String

Unique technical (not for the traveller) identifier for the FareAttribute

price: String

Fare price, in the unit specified by FareAttribute::currency

currency: String

Currency used to pay the fare.

payment_method: PaymentMethod

Indicates when the fare must be paid

transfers: Transfers

Indicates the number of transfers permitted on this fare

agency_id: Option<String>

Identifies the relevant agency for a fare

transfer_duration: Option<usize>

Length of time in seconds before a transfer expires