pub struct Frequency {
    pub start_time: u32,
    pub end_time: u32,
    pub headway_secs: u32,
    pub exact_times: Option<ExactTimes>,
}
Timetables can be defined by the frequency of their vehicles. See <https://gtfs.org/reference/static/#frequenciestxt>

Fields

start_time: u32

Time at which the first vehicle departs from the first stop of the trip

end_time: u32

Time at which service changes to a different headway (or ceases) at the first stop in the trip

headway_secs: u32

Time, in seconds, between departures from the same stop (headway) for the trip, during the time interval specified by start_time and end_time

exact_times: Option<ExactTimes>

Indicates the type of service for a trip

Implementations

Converts from a RawFrequency to a Frequency