Struct gtfs_structures::RawFrequency
source · pub struct RawFrequency {
pub trip_id: String,
pub start_time: u32,
pub end_time: u32,
pub headway_secs: u32,
pub exact_times: Option<ExactTimes>,
}Fields
trip_id: StringReferences the Trip that uses frequency
start_time: u32Time at which the first vehicle departs from the first stop of the trip
end_time: u32Time at which service changes to a different headway (or ceases) at the first stop in the trip
headway_secs: u32Time, in seconds, between departures from the same stop (headway) for the trip, during the time interval specified by start_time and end_time
exact_times: Option<ExactTimes>Indicates the type of service for a trip