pub struct RawTrip {
pub id: String,
pub service_id: String,
pub route_id: String,
pub shape_id: Option<String>,
pub trip_headsign: Option<String>,
pub trip_short_name: Option<String>,
pub direction_id: Option<DirectionType>,
pub block_id: Option<String>,
pub wheelchair_accessible: Availability,
pub bikes_allowed: BikesAllowedType,
pub ticketing_trip_id: Option<String>,
pub ticketing_type: TicketingType,
}Expand description
A Trip where the relationships with other objects have not been checked
Fields
id: StringUnique technical (not for the traveller) identifier for the Trip
service_id: StringReferences the Calendar on which this trip runs
route_id: StringReferences along which Route this trip runs
shape_id: Option<String>Shape of the trip
trip_headsign: Option<String>Text that appears on signage identifying the trip’s destination to riders
trip_short_name: Option<String>Public facing text used to identify the trip to riders, for instance, to identify train numbers for commuter rail trips
direction_id: Option<DirectionType>Indicates the direction of travel for a trip. This field is not used in routing; it provides a way to separate trips by direction when publishing time tables
block_id: Option<String>Identifies the block to which the trip belongs. A block consists of a single trip or many sequential trips made using the same vehicle, defined by shared service days and block_id. A block_id can have trips with different service days, making distinct blocks
wheelchair_accessible: AvailabilityIndicates wheelchair accessibility
bikes_allowed: BikesAllowedTypeIndicates whether bikes are allowed
ticketing_trip_id: Option<String>This field is not part of the main GTFS specification, it is part of the Google Transit Ticketing extension Trip ID to pass to a ticket shop
ticketing_type: TicketingTypeThis field is not part of the main GTFS specification, it is part of the Google Transit Ticketing extension Enable or disable buying tickets via a deep link