Struct gtfs_structures::Shape

source ·
pub struct Shape {
    pub id: String,
    pub latitude: f64,
    pub longitude: f64,
    pub sequence: usize,
    pub dist_traveled: Option<f32>,
}
A single geographical point decribing the shape of a Trip. See https://gtfs.org/reference/static/#shapestxt

Fields

id: String

Unique technical (not for the traveller) identifier for the Shape

latitude: f64

Latitude of a shape point

longitude: f64

Longitude of a shape point

sequence: usize

Sequence in which the shape points connect to form the shape. Values increase along the trip but do not need to be consecutive.

dist_traveled: Option<f32>

Actual distance traveled along the shape from the first shape point to the point specified in this record. Used by trip planners to show the correct portion of the shape on a map