Struct gtfs_structures::Stop
source · pub struct Stop {Show 16 fields
pub id: String,
pub code: Option<String>,
pub name: String,
pub description: String,
pub location_type: LocationType,
pub parent_station: Option<String>,
pub zone_id: Option<String>,
pub url: Option<String>,
pub longitude: Option<f64>,
pub latitude: Option<f64>,
pub timezone: Option<String>,
pub wheelchair_boarding: Availability,
pub level_id: Option<String>,
pub platform_code: Option<String>,
pub transfers: Vec<StopTransfer>,
pub pathways: Vec<Pathway>,
}Expand description
A physical stop, station or area. See https://gtfs.org/reference/static/#stopstxt
Fields
id: StringUnique technical identifier (not for the traveller) of the stop
code: Option<String>Short text or a number that identifies the location for riders
name: StringName of the location. Use a name that people will understand in the local and tourist vernacular
description: StringDescription of the location that provides useful, quality information
location_type: LocationTypeType of the location
parent_station: Option<String>Defines hierarchy between the different locations
zone_id: Option<String>Identifies the fare zone for a stop
url: Option<String>URL of a web page about the location
longitude: Option<f64>Longitude of the stop
latitude: Option<f64>Latitude of the stop
timezone: Option<String>Timezone of the location
wheelchair_boarding: AvailabilityIndicates whether wheelchair boardings are possible from the location
level_id: Option<String>Level of the location. The same level can be used by multiple unlinked stations
platform_code: Option<String>Platform identifier for a platform stop (a stop belonging to a station)
transfers: Vec<StopTransfer>Transfers from this Stop
pathways: Vec<Pathway>Pathways from this stop