pub struct TicketingDeepLink {
pub ticketing_deep_link_id: String,
pub web_url: Option<String>,
pub android_intent_url: Option<String>,
pub ios_universal_link_url: Option<String>,
}Expand description
This object is not part of the main GTFS specification, it is part of the Google Transit Ticketing extension The base url to a ticket shop without the trip specific parameters
Fields
ticketing_deep_link_id: StringUnique identifier for this base link
web_url: Option<String>URL to be used for buying a ticket on the web
android_intent_url: Option<String>URI to be used for buying a ticket in an android app
ios_universal_link_url: Option<String>URL used to use on iOS