pub struct TicketingIdentifier {
pub ticketing_stop_id: String,
pub stop_id: String,
pub agency_id: String,
}Expand description
This object is not part of the main GTFS specification, it is part of the Google Transit Ticketing extension A mapping of the GTFS-identifiers to the ticket shop identifiers
Fields
ticketing_stop_id: StringStop ID used by the ticket shop
stop_id: StringGTFS-side stop id
agency_id: StringGTFS-side agency id