Struct gtfs_structures::FareAttribute
source · pub struct FareAttribute {
pub id: String,
pub price: String,
pub currency: String,
pub payment_method: PaymentMethod,
pub transfers: Transfers,
pub agency_id: Option<String>,
pub transfer_duration: Option<usize>,
}Expand description
Defines one possible fare. See https://gtfs.org/reference/static/#fare_attributestxt
Fields
id: StringUnique technical (not for the traveller) identifier for the FareAttribute
price: StringFare price, in the unit specified by FareAttribute::currency
currency: StringCurrency used to pay the fare.
payment_method: PaymentMethodIndicates when the fare must be paid
transfers: TransfersIndicates the number of transfers permitted on this fare
agency_id: Option<String>Identifies the relevant agency for a fare
transfer_duration: Option<usize>Length of time in seconds before a transfer expires